Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4102)

Unified Diff: chrome/browser/ui/webui/plugins_ui.cc

Issue 893823002: Register system Pepper Flash plugin if no packaged Pepper plugin is found. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: better mac support Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/plugins_ui.cc
diff --git a/chrome/browser/ui/webui/plugins_ui.cc b/chrome/browser/ui/webui/plugins_ui.cc
index 09afd464022c7ec3c22285faa978055c472ea6af..0735b779565b678ef31ddb87d4ff5a467a7dfcf5 100644
--- a/chrome/browser/ui/webui/plugins_ui.cc
+++ b/chrome/browser/ui/webui/plugins_ui.cc
@@ -372,16 +372,16 @@ void PluginsDOMHandler::PluginsLoaded(
plugin_file->SetString("name", group_plugin.name);
// If this plugin is Pepper Flash, and the plugin path is the same as the
// path for the Pepper Flash Debugger plugin, then mark this plugin
// description as the debugger plugin to help the user disambiguate the
// two plugins.
base::string16 desc = group_plugin.desc;
if (group_plugin.is_pepper_plugin() &&
group_plugin.name == base::ASCIIToUTF16(content::kFlashPluginName)) {
base::FilePath debug_path;
- PathService::Get(chrome::DIR_PEPPER_FLASH_DEBUGGER_PLUGIN, &debug_path);
+ PathService::Get(chrome::DIR_PEPPER_FLASH_SYSTEM_PLUGIN, &debug_path);
if (group_plugin.path.DirName() == debug_path)
- desc += base::ASCIIToUTF16(" Debug");
+ desc += base::ASCIIToUTF16(" System");
}
plugin_file->SetString("description", desc);
@@ -372,16 +372,16 @@ void PluginsDOMHandler::PluginsLoaded(
plugin_file->SetString("name", group_plugin.name);
// If this plugin is Pepper Flash, and the plugin path is the same as the
- // path for the Pepper Flash Debugger plugin, then mark this plugin
- // description as the debugger plugin to help the user disambiguate the
+ // path for the Pepper Flash System plugin, then mark this plugin
+ // description as the system plugin to help the user disambiguate the
// two plugins.
base::string16 desc = group_plugin.desc;

Powered by Google App Engine
This is Rietveld 408576698